@@ -4,6 +4,7 @@ import itertools
 import math
 from functools import lru_cache
 from typing import (
+    Any,
     Callable,
     Collection,
     Dict,
@@ -19,6 +20,7 @@ from typing import (
     Tuple,
     Union,
 )
+from warnings import warn
 
 import matplotlib.cm as cm
 import networkx as nx
@@ -54,7 +56,7 @@ class MACIDBase(CausalBayesianNetwork):
     class Model(CausalBayesianNetwork.Model):
         def __setitem__(self, variable: str, relationship: Union[Relationship, Sequence]) -> None:
             if isinstance(relationship, (DecisionDomain, Sequence)) and variable not in self.cbn.decisions:
-                raise ValueError(f"trying to add DecisionDomain to non-decision node {variable}")
+                warn(f"adding DecisionDomain to non-decision node {variable}")
             super().__setitem__(variable, relationship)
 
         def to_tabular_cpd(self, variable: str, relationship: Union[Relationship, Sequence[Outcome]]) -> TabularCPD:
@@ -65,9 +67,10 @@ class MACIDBase(CausalBayesianNetwork):
 
     def __init__(
         self,
-        edges: Iterable[Tuple[str, str]],
-        agent_decisions: Mapping[AgentLabel, Iterable[str]],
-        agent_utilities: Mapping[AgentLabel, Iterable[str]],
+        edges: Iterable[Tuple[str, str]] = None,
+        agent_decisions: Mapping[AgentLabel, List[str]] = None,
+        agent_utilities: Mapping[AgentLabel, List[str]] = None,
+        **kwargs: Any,
     ):
         """Initialize a new MACIDBase instance.
 
@@ -81,10 +84,10 @@ class MACIDBase(CausalBayesianNetwork):
         agent_utilities: The utility nodes of each agent.
             A mapping of agent label => node labels.
         """
-        super().__init__(edges=edges)
+        super().__init__(edges=edges, **kwargs)
 
-        self.agent_decisions = {agent: list(nodes) for agent, nodes in agent_decisions.items()}
-        self.agent_utilities = {agent: list(nodes) for agent, nodes in agent_utilities.items()}
+        self.agent_decisions = dict(agent_decisions) if agent_decisions else {}
+        self.agent_utilities = dict(agent_utilities) if agent_utilities else {}
 
         self.decision_agent = {node: agent for agent, nodes in self.agent_decisions.items() for node in nodes}
         self.utility_agent = {node: agent for agent, nodes in self.agent_utilities.items() for node in nodes}
@@ -109,16 +112,19 @@ class MACIDBase(CausalBayesianNetwork):
         - agent specifies which agent the decision node should belong to in a MACID.
         """
         self.make_chance(node)
-        self.agent_decisions[agent].append(node)
+        if agent not in self.agent_decisions:
+            self.agent_decisions[agent] = [node]
+        else:
+            self.agent_decisions[agent].append(node)
         self.decision_agent[node] = agent
-        cpd = self.get_cpds(node)
-        if cpd and not isinstance(cpd, DecisionDomain):
-            self.add_cpds(DecisionDomain(node, self, cpd.state_names[node]))
 
     def make_utility(self, node: str, agent: AgentLabel = 0) -> None:
         """ "Turn a chance or utility node into a decision node."""
         self.make_chance(node)
-        self.agent_utilities[agent].append(node)
+        if agent not in self.agent_utilities:
+            self.agent_utilities[agent] = [node]
+        else:
+            self.agent_utilities[agent].append(node)
         self.utility_agent[node] = agent
 
     def make_chance(self, node: str) -> None:
@@ -164,7 +170,7 @@ class MACIDBase(CausalBayesianNetwork):
                 mech_graph.remove_edge(parent, intervention_var)
         for decision in self.decisions:
             for query_node in query:
-                if mech_graph.is_active_trail(
+                if mech_graph.is_dconnected(
                     decision + "mec", query_node, observed=list(context.keys()) + list(intervention.keys())
                 ):
                     cpd = self.get_cpds(decision)
@@ -244,7 +250,7 @@ class MACIDBase(CausalBayesianNetwork):
                 con_nodes = [decision] + self.get_parents(decision)
                 agent_utilities = self.agent_utilities[self.decision_agent[decision]]
                 for utility in set(agent_utilities).intersection(nx.descendants(self, decision)):
-                    if mg.is_active_trail(node + "mec", utility, con_nodes):
+                    if mg.is_dconnected(node + "mec", utility, con_nodes):
                         return True
         return False
 
@@ -409,17 +415,21 @@ class MACIDBase(CausalBayesianNetwork):
     # Really, DAG.active_trail_nodes should accept Sets, especially since it does
     # inefficient membership checks on observed as a list.
     def active_trail_nodes(
-        self, variables: Union[str, List[str], Tuple[str, ...]], observed: Optional[Iterable[str]] = None
+        self, variables: Union[str, List[str], Tuple[str, ...]], observed: Optional[Iterable[str]] = None, **kwargs: Any
     ) -> Dict[str, Set[str]]:
-        return super().active_trail_nodes(variables, list(observed))  # type: ignore
+        return super().active_trail_nodes(variables, list(observed), **kwargs)  # type: ignore
 
     def copy_without_cpds(self) -> MACIDBase:
         """copy the MACIDBase object without its CPDs"""
-        return MACIDBase(
-            edges=self.edges(),
-            agent_decisions=self.agent_decisions,
-            agent_utilities=self.agent_utilities,
-        )
+        new = MACIDBase()
+        new.add_nodes_from(self.nodes)
+        new.add_edges_from(self.edges)
+        for agent in self.agents:
+            for decision in self.agent_decisions[agent]:
+                new.make_decision(decision, agent)
+            for utility in self.agent_utilities[agent]:
+                new.make_utility(utility, agent)
+        return new
 
     def _get_color(self, node: str) -> Union[np.ndarray, str]:
         """
